@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Request::CreateBucket;
-use Moose;
+use Moose 0.85;
 extends 'Net::Amazon::S3::Request';
 
 has 'bucket'    => ( is => 'ro', isa => 'BucketName',      required => 1 );
